<?php
/**
 *	Nensor Content Management
 *  Copyright (C) 2009 Sem Kokhuis, www.nensor.com
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *	This source file is subject to the General Public License (GPL)
 * 	that is bundled with this package in the file LICENSE.txt.
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

abstract class Payment {
  protected $_post = array();
  protected $_merchantKey = '';
  protected $_secretKey = '';
  protected $_url = '';
  protected $_totalprice;
  protected $_invoice;
  protected $_fields = array('BPE_Merchant' => '', 
                           'BPE_Currency' => '',
                           'BPE_Amount' => '',                           
                           'BPE_Description' => '',
                           'BPE_Reference' => '',
                           'BPE_Invoice' => '',
                           'BPE_Signature2' => '',
                           'BPE_Mode' => '',
                           'BPE_Language' => '',
                           'BPE_Return_Success' => '',
                           'BPE_Return_Reject' => '',
                           'BPE_Return_Error' => '',
                           'BPE_Return_Method' => '',
                           'BPE_Return_Target' => '',
                           'BPE_Style' => '');
  protected $_modus = array('0', '1');
  protected $_languages = array('NL', 'EN', 'FR', 'DE');
  
  public function __construct($invoice = '', $totalprice = 0) {
    $this->_merchantKey = Get_Value('shop_sMerchantKey');
    $this->_secretKey = Get_Value('shop_sSecretKey');
  	if($invoice != '' && $totalprice > 0) {
	    $this->_totalprice = $totalprice;
	    $this->_invoice = $invoice;
	    $this->init();
		}
  }
  
	private function getKey($invoice) {
		return substr($invoice, 8, strlen($invoice) - 8);
	}
	
  private function createHash() {
    if($this->_merchantKey != '' &&
       $this->_fields['BPE_Invoice'] != '' &&
       $this->_secretKey != '') {
         if($this->_fields['BPE_Amount'] > 0 &&
            is_int($this->_fields['BPE_Amount'])) {
              if($this->_fields['BPE_Mode'] != '' && ($this->_fields['BPE_Mode'] == '0' || $this->_fields['BPE_Mode'] == '1')) {
                $hash_string = $this->_merchantKey . $this->_fields['BPE_Invoice'] . $this->_fields['BPE_Amount'] . $this->_fields['BPE_Currency'] . $this->_fields['BPE_Mode'] . $this->_secretKey;
                return md5($hash_string);
              }
              else {
                throw new Exception('BPE_Mode can only be 0 or 1 not '.$this->_fields['BPE_Mode']);
              }
         }
         else {
           throw new Exception('BPE_Amount must be numeric not '.$this->_fields['BPE_Amount']);
         }
    }
    else {
      throw new Exception('MerchantKey, BPE_Invoice and SecretKey cannot be empty or null');
    }
  }
  
  private function checkHash() {
    if(!is_null($this->_post) && count($this->_post) > 0) {
      if($this->_merchantKey != '' && 
         $this->_secretKey != '' &&
         $this->_post['bpe_trx'] != '') {
           $hash_string = $this->_post['bpe_trx'] . $this->_post['bpe_timestamp'] . $this->_merchantKey . $this->_post['bpe_invoice'] . $this->_post['bpe_reference'] . $this->_post['bpe_currency'] . $this->_post['bpe_amount'] . $this->_post['bpe_result'] . $this->_post['bpe_mode'] .$this->_secretKey;
					 $hash = md5($hash_string);
           return $hash == $this->_post[bpe_signature2];
      }
      else {
        throw new Exception('POST from Buckaroo cannot be verified. Empty fields encountered<br />'.print_r($this->_post, true));
      }
    }
    else 
      throw new Exception("POST not set");
  }

  abstract function getForm();
  
	public function process($post) {
		if(is_array($post)) {
      $this->_post = $post;
		  $this->writeXmlLog();
			if($this->checkHash()) {
				$this->updateTrx($this->getKey($this->_post['bpe_invoice']), $this->_post['bpe_trx']);
				//$this->updateResult($this->_post['bpe_trx'], $this->_post['bpe_result'] . ' - ' . $this->_codes[$this->_post['bpe_result']]);
			}
			else
				throw new Exception('Hash cannot be verified');
		}
		else
			throw new Exception('$_POST not set.');
	}
	
  private function createXmlLog() {
    if(!is_dir('media/buckaroo'))
      mkdir('media/buckaroo');
    $doc = new DomDocument();
    $root = $doc->createElement('results');
    $doc->appendChild($root);
    $doc->save('media/buckaroo/results.xml');
  }
  
	abstract function redirect();
	
  protected function init() {
    global $sSiteLanguage;
    $this->_fields['BPE_Merchant'] = $this->_merchantKey;
    $this->_fields['BPE_Mode'] = Get_Value('shop_bIsTest');
    $this->_fields['BPE_Currency'] = 'EUR';
    $this->_fields['BPE_Amount'] = (int)number_format($this->_totalprice, 2, "", "");
    $this->_fields['BPE_Description'] = "Order " . $_SERVER['HTTP_HOST'];
    $this->_fields['BPE_Reference'] = '';
    $this->_fields['BPE_Language'] = (in_array(strtoupper($sSiteLanguage), $this->_languages) ? strtoupper($sSiteLanguage) : 'EN');
    $this->_fields['BPE_Invoice'] = $this->_invoice;
    $this->_fields['BPE_Return_Method'] = 'POST';
    $this->_fields['BPE_Return_Target'] = 'payopener';
    $this->_fields['BPE_Style'] = 'POPUP';
    $this->_fields['BPE_Signature2'] = $this->createHash();
  }
  
	protected function updateTrx($key, $trx) {
    $sql = "UPDATE `tb_shop_orders` SET `sTrx` = '$trx' WHERE `iKey` = $key";
    mysql_query($sql) or die(mysql_error()."<br />".$sql);
	}
	
  protected function updateResult($trxid, $result) {
    $sql = "UPDATE `tb_shop_orders` SET `sBpeResult` = '$result' WHERE `sTrx` = '$trxid'";
    mysql_query($sql) or die(mysql_error()."<br />".$sql);
  }
  
  protected function updateStatus($trxid, $status) {
    $sql = "UPDATE `tb_shop_orders` SET `iKeyStatus` = $status WHERE `sTrx` = '$trxid'";
    mysql_query($sql) or die(mysql_error()."<br />".$sql);
  }
  
  protected function getFields() {
    $fields = '';

    foreach($this->_fields as $field => $value) {
      $fields .= '<input type="hidden" name="'.$field.'" value="'.$value.'" />'."\r\n";
    }
    return $fields;
  }
	
  protected function showMessage() {
  	echo translate("Buckaroo_response_error")."<br /><br />";
  	echo "Invoice: ".$this->_post['bpe_invoice']."<br />";
  	echo "Error: ".$this->_post['bpe_result']."<br />";
  }
  
  protected function writeXmlLog() {
    if(!file_exists('media/buckaroo/results.xml')) {
      $this->createXmlLog();
    }
      
    $doc = new DOMDocument();
    $doc->load('media/buckaroo/results.xml');
    $nodes = $doc->getElementsByTagName('results');
    $root = $nodes->item(0);
    $result = $doc->createElement('result');
    $result->setAttribute('timestamp', date('Y-m-d H:i:s'));
    foreach($this->_post as $name=>$value) {
      $element = $doc->createElement($name, $value);
      $result->appendChild($element);
    }
    $root->appendChild($result);
    $doc->save('media/buckaroo/results.xml');
  }
  
	public function sendMail($payed = false, $toAdmin = true) {
	  global $aGet;
		// Mail
		$iKeyOrder = $this->getKey($this->_post['bpe_invoice']);
		$domain = str_replace("http://","",str_replace("www.","",$_SERVER['HTTP_HOST']));
		$sql = "SELECT * FROM tb_extra_mail_templates WHERE iKey=2 AND sLanguageAbbr='".strtolower($_SESSION[SESSION."website_language"])."'";
		$aMail = getTableColumns($sql);
		if(!is_array($aMail)){ // Default to NL
			$sql = "SELECT * FROM tb_extra_mail_templates WHERE iKey=2 AND sLanguageAbbr='nl'";
			$aMail = getTableColumns($sql);
		}
	
		$sFrom = (isset($aMail["sFrom"]) && $aMail["sFrom"] != "") ? $aMail["sFrom"]."@".$domain : translate("Bestelling")."@".$domain;
		$sFromName = (isset($aMail["sFromName"]) && $aMail["sFromName"] != "") ? $aMail["sFromName"] : translate("Bestelling")." ".$domain;
	
		$sOrder = getOrder($iKeyOrder,"language=original&showordernr=1&showaddress=0&showorder=1");
		$sAddress = getOrder($iKeyOrder,"language=original&showordernr=0&showaddress=1&showorder=0");
	
		$sTo = $_SESSION[SESSION."shoporder1"]["sMail"];
	
		$sSubject = $aMail["sSubject"];
		$sSubject = str_replace("[DOMAIN]","http://".$domain,$sSubject);
		$sSubject = str_replace("[BESTELLING]",$sOrder,$sSubject);
		$sSubject = str_replace("[VOORNAAM]",$_SESSION[SESSION."shoporder1"]['sFirstname'],$sSubject);
		$sSubject = str_replace("[ACHTERNAAM]",$_SESSION[SESSION."shoporder1"]['sLastname'],$sSubject);
		$sSubject = str_replace("[ADRESGEGEVENS]",$sAddress,$sSubject);
	
		$sBody = $aMail["sBody"];
	
		$sBody = str_replace(chr(13),"<br />",$sBody);
		$sBody = str_replace("[DOMAIN]","http://".$domain,$sBody);
		$sBody = str_replace("[BESTELLING]",$sOrder,$sBody);
		$sBody = str_replace("[VOORNAAM]",$_SESSION[SESSION."shoporder1"]['sFirstname'],$sBody);
		$sBody = str_replace("[ACHTERNAAM]",$_SESSION[SESSION."shoporder1"]['sLastname'],$sBody);
		$sBody = str_replace("[ADRESGEGEVENS]",$sAddress,$sBody);
		$sBody = str_replace('[KLANTOPMERKING]', $_SESSION[SESSION."shoporder1"]["sAdminText"], $sBody);
		//$sFrom = "sem@nensor.com";
		//$sTo = "s.kokhuis@chello.nl";
	
		//sendmail($sFrom,$sFromName,$sTo,$sSubject,$sBody);

		if($toAdmin) {
			// Send mail to addresses in shop config
			if(Get_Value("shop_sMailOrderTo")!=""){
				$aMailTo = split(";",Get_Value("shop_sMailOrderTo"));
				for($i=0;$i<count($aMailTo);$i++){
					sendmail($sFrom,$sFromName,$aMailTo[$i],($payed ? "BETAALD: ".$sSubject : $sSubject),$sBody);
				}
			}
		}
	}
}
?>