/**
 *	Nensor Content Management
 *  Copyright (C) 2009 Sem Kokhuis, www.nensor.com
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *	This source file is subject to the General Public License (GPL)
 * 	that is bundled with this package in the file LICENSE.txt.
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

Ext.grid.TableGrid = function(table, config) {
    config = config || {};
    var cf = config.fields || [], ch = config.columns || [];
    table = Ext.get(table);

    var ct = table.insertSibling();

    var fields = [], cols = [];
    var headers = table.query("thead th");
	for (var i = 0, h; h = headers[i]; i++) {
		var text = h.innerHTML;
		var name = 'tcol-'+i;

        fields.push(Ext.applyIf(cf[i] || {}, {
            name: name,
            mapping: 'td:nth('+(i+1)+')/@innerHTML'
        }));

		cols.push(Ext.applyIf(ch[i] || {}, {
			'header': text,
			'dataIndex': name,
			'width': h.offsetWidth,
			'tooltip': h.title,
            'sortable': false
        }));
	}

    var ds  = new Ext.data.Store({
        reader: new Ext.data.XmlReader({
            record:'tbody tr'
        }, fields)
    });

	ds.loadData(table.dom);

    var cm = new Ext.grid.ColumnModel(cols);

    if(config.width || config.height){
        ct.setSize(config.width || 'auto', config.height || 'auto');
    }
    if(config.remove !== false){
        table.remove();
    }

    Ext.grid.TableGrid.superclass.constructor.call(this, ct,
        Ext.applyIf(config, {
            'ds': ds,
            'cm': cm,
            'sm': new Ext.grid.RowSelectionModel(),
            autoHeight:true,
            autoWidth:true
        }
    ));
};

Ext.extend(Ext.grid.TableGrid, Ext.grid.Grid);

Ext.grid.GridStateManager2 = function(){  
    this.state = {};  
};

/**  
Initialises <code>grid</code> with states in <code>provider</code>.  
    
@param {Grid} grid  
@param {Provider} provider  
*/  
Ext.grid.GridStateManager2.prototype = { 
    init : function(grid, provider) {  
    this.provider = provider;  
    this.grid = grid;  
  
    this.cm = grid.getColumnModel();  
    this.ds = grid.getDataSource();  
    //save a copy of the default config object. There has GOT to be a better way to clone an object... 
    this.origConfig = Ext.util.JSON.decode(Ext.util.JSON.encode(this.cm.config)); 
    // Get the state to be restored to the grid. //  
    var state = provider.get(this.getStateKey());  
      
    if ( state ) {  
        this.restoreState(state); 
    }  

    // Set listeners on all events that relate to grid changes.  
    // Hence, state should be updated every time the grid changes.  
    // You might want to do this differently. E.g. save state when a user presses a button; when the page unloads, etc.  
    //  
    function setState() {  
        this.updateState();  
        this.storeState();  
    }  
    // NB: widthchange event on ColumnModel does not fire when columns are resized. Must use grid columnresize event.  
    grid.on("columnresize", setState, this);  
    this.cm.on("hiddenchange", setState, this);  
    this.cm.on("columnlockchange", setState, this);  
    this.cm.on("columnmoved", setState, this);  
    //this.ds.on("datachanged", setState, this);  
  }, 
  storeState : function() {  
    this.provider.set(this.getStateKey(), this.state);  
  }, 
    restoreState : function(state){ 
        var col, colConfig, config, i, sort; 
        if ( "config" in state ) {  
            config = state.config;  
          
            // Restore Column Model config.  
            for (i = 0; i < config.length; i++) {  
                colConfig = config[i];  
                col = this.cm.getIndexById(colConfig.id);  
                if (col != -1) {  
                    if (col != i) {  
                        this.cm.moveColumn(col, i);  
                    }  
                    if ( "hidden" in colConfig ) {  
                        this.cm.setHidden(i, colConfig.hidden);  
                    } else { 
                        this.cm.setHidden(i, false); 
                                        } 
                    if ( "locked" in colConfig ) {  
                        this.cm.setLocked(i, colConfig.locked);  
                    }  else { 
                        this.cm.setLocked(i, 'false'); 
                                        } 
                    if ( "width" in colConfig ) {  
                        this.cm.setColumnWidth(i, colConfig.width);  
                    }  
                }  
            }  
        }  
     /* 
        if ( "sortInfo" in state ) {  
            var sortInfo = state.sortInfo;  
            if ( ("field" in sortInfo) && ("direction" in sortInfo) ) {  
                this.ds.setDefaultSort(sortInfo.field, sortInfo.direction);  
                // If local, might want to sort straight away as well...  
            }  
        }  
      */ 
    }, 
    resetState: function(){ 
             this.state.config = this.origConfig; 
             this.restoreState(this.state); 
    }, 
           getStateKey : function() {  
             return this.grid.id + "-grid-state";   
    } ,   
    updateState : function() {  
             var cm = this.grid.getColumnModel();  
             var ds = this.grid.getDataSource();  
             var state = this.state;  

    // Copy the current sort column/direction.  
    var sortState = ds.getSortState(); // {field: "..dataIndex of sort field..", direction: "ASC"|"DESC"}  
    if ( typeof(sortState) == "object" ) {  
        if ( ("field" in sortState) && ("direction" in sortState) ) {  
            state.sortInfo = {};  
            state.sortInfo.field = sortState.field;  
            state.sortInfo.direction = sortState.direction;   
        }  
    }  
      
    // Copy column model config array.  
    var c = []; 
        for (var i = 0; i < cm.config.length; i++) { 
            c.push({id:cm.config[i].id, 
                hidden:cm.config[i].hidden, 
                width:cm.config[i].width, 
                locked:cm.config[i].locked 
            }); 
        } 
        var obj = Ext.encode(c);  
    state.config = Ext.decode(obj);  
    } 
};  

Ext.apply(Ext.grid.Grid.prototype, { 
  restoreState: function (provider) { 
    if (!provider) { 
      provider = Ext.state.Manager; 
    } 
    this.sm = new Ext.grid.GridStateManager2(); 
    this.sm.init(this, provider);     
  }, 
    getStateManager : function(){ 
        return this.sm; 
    } 
}); 